.. _parameters_and_distributions:

Parameters and distributions
============================

This page describes the format of the expected parameters and distributions used by NeuroTS.


.. _params:

Parameters
----------

.. _params_schema:

Schema
~~~~~~

.. jsonschema:: ../../neurots/schemas/parameters.json
    :lift_definitions:
    :auto_reference:
    :auto_target:

.. _params_example:

Example
~~~~~~~

.. literalinclude:: ../../tests/data/params1_orientation_manager.json
   :linenos:


.. _distrs:

Distributions
-------------

.. _distrs_schema:

Schema
~~~~~~

.. jsonschema:: ../../neurots/schemas/distributions.json
    :lift_definitions:
    :auto_reference:
    :auto_target:

.. _distrs_example:

Example
~~~~~~~

.. literalinclude:: ../../tests/data/bio_distribution_apical_point.json
   :linenos:
